# Other software

Æ-DIR
  web2ldap is used as administration front-end for Æ-DIR mainly with the help of a special plugin module. See the user guide for details.
OATH-LDAP
  web2ldap provides a special plugin module for maintaining OATH-LDAP entries, e.g. used in Æ-DIR.

# Talks

Presentation 2013-10-19 at LDAPcon 2013

  Do The Right Thing! How LDAP servers should help LDAP clients (download PDF)

  "This talk is about the highs and lows of implementing a generic interactive LDAP client with web2ldap to be shown as example (because the author is biased of course)."

OpenLDAP Developers' Day
  web2ldap was presented at the OpenLDAP Developers' Day - Tübingen - 2006 (download slides).